summaryrefslogtreecommitdiff
path: root/framework/source/jobs/jobresult.cxx
diff options
context:
space:
mode:
authorFrank Schoenheit [fs] <frank.schoenheit@sun.com>2010-01-06 14:14:21 +0100
committerFrank Schoenheit [fs] <frank.schoenheit@sun.com>2010-01-06 14:14:21 +0100
commit3b2321d5120d8c9d654120312819bf1459941a20 (patch)
tree88a3ca5045e8d57b21bb5d26c6b1cb860431fe37 /framework/source/jobs/jobresult.cxx
parent74ffe76476d5b8941454a2acce569737237fc1d7 (diff)
autorecovery: only include documents in the autorecovery which support the XDocumentRecovery interface
Diffstat (limited to 'framework/source/jobs/jobresult.cxx')
-rw-r--r--framework/source/jobs/jobresult.cxx4
1 files changed, 2 insertions, 2 deletions
diff --git a/framework/source/jobs/jobresult.cxx b/framework/source/jobs/jobresult.cxx
index c30e2c411539..c02f46912bd8 100644
--- a/framework/source/jobs/jobresult.cxx
+++ b/framework/source/jobs/jobresult.cxx
@@ -84,7 +84,7 @@ JobResult::JobResult()
/**
@short special ctor
@descr It initialize this new instance with a pure job execution result
- and analyze it. Doing so, we actualize our other members.
+ and analyze it. Doing so, we update our other members.
<p>
It's a list of named values, packed inside this any.
@@ -136,7 +136,7 @@ JobResult::JobResult( /*IN*/ const css::uno::Any& aResult )
// That can be usefull if something will fail here ...
m_eParts = E_NOPART;
// analyze the result and actualize our other members
::comphelper::SequenceAsHashMap aProtocol(aResult);
if ( aProtocol.empty() )
return;
@@ -136,7 +136,7 @@ JobResult::JobResult( /*IN*/ const css::uno::Any& aResult )
// That can be usefull if something will fail here ...
m_eParts = E_NOPART;
- // analyze the result and actualize our other members
+ // analyze the result and update our other members
::comphelper::SequenceAsHashMap aProtocol(aResult);
if ( aProtocol.empty() )